.. Flippers documentation master file, created by
   sphinx-quickstart on Sun Mar 26 01:49:07 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Flippers's documentation!
====================================


.. toctree::
   :maxdepth: 2
   :caption: API Reference
   :hidden:

   reference/flippers

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`